@@ -39,7 +39,11 @@ KEduVocDocument::ErrorCode KEduVocWqlReader::read(KEduVocDocument &doc)
     m_doc = &doc;
 
     QTextStream inputStream( m_inputFile );
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0) //TODO fix in qt6!
     inputStream.setCodec( "Windows-1252" ); //("ISO-8851-1");
+#else
+    qWarning() << " Need to fix inputStream.setCodec( Windows-1252 );";
+#endif
     inputStream.setAutoDetectUnicode( false );
     inputStream.seek( 0 );
 
@@ -50,7 +54,7 @@ KEduVocDocument::ErrorCode KEduVocWqlReader::read(KEduVocDocument &doc)
         return KEduVocDocument::FileTypeUnknown;
     }
     s = inputStream.readLine();
-    s = s.left( 1 );
+    s = s.at( 1 );
     int iFV = s.toInt( 0 );
     if ( iFV != 5 ) {
         m_errorMessage = i18n( "Only files created by WordQuiz 5.x or later can be opened: Missing Second Line \"5\"" );
